@@ -5,7 +5,7 @@ if not IS_BUILD_MODE:
 
 
 
-__version__='0.0.8'
+__version__='0.1.0'
 
 
 
@@ -139,18 +139,20 @@ def download(args):
                 f.write('0')
         auth = oss2.Auth(id, secret)
         bucket = oss2.Bucket(auth, endpoint, bucket_name)
-        bucket.get_object_to_file(object_name, local_path)
+        
+        for o,l in zip(object_name, local_path):
+            bucket.get_object_to_file(o, l)
+            if use_tar:
+                target_dir = os.path.dirname(l)
+                tar = tarfile.open(l, "r:gz")
+                filenames = tar.getnames()
+                for fn in filenames:
+                    tar.extract(fn, target_dir)
+                tar.close()
+                os.remove(l)
         if use_control_signal:
             with open(signal_path, 'w') as f:
                 f.write('1')
-        if use_tar:
-            target_dir = os.path.dirname(local_path)
-            tar = tarfile.open(local_path, "r:gz")
-            filenames = tar.getnames()
-            for fn in filenames:
-                tar.extract(fn, target_dir)
-            tar.close()
-            os.remove(local_path)
 
     except:
         if use_control_signal:
@@ -171,7 +173,7 @@ def run():
     up_parser.add_argument('--bucket', type=str, default='',help='bucket name')
     up_parser.add_argument('--local', type=str, default='', help='local path')
     up_parser.add_argument('--object', type=str, default='', help='object name')
-    up_parser.add_argument('--endpoint', type=str, default='oss-cn-shanghai-internal.aliyuncs.com', help='endpoint')
+    up_parser.add_argument('--endpoint', type=str, default='', help='endpoint')
     up_parser.add_argument('--use_tar', action='store_true', help='compress the give local file')
     up_parser.add_argument('--use_control_signal', action='store_true', help='write control signal in file')
     up_parser.add_argument('--signal_path', type=str, default='/tmp/ossctl-signal', help='path to write signal')
@@ -182,9 +184,9 @@ def run():
     down_parser.add_argument('--id', type=str, default='', help='Aliyun account id')
     down_parser.add_argument('--secret', type=str, default='', help='Aliyun account secret')
     down_parser.add_argument('--bucket', type=str, default='',help='bucket name')
-    down_parser.add_argument('--local', type=str, default='', help='local path')
-    down_parser.add_argument('--object', type=str, default='', help='object name')
-    down_parser.add_argument('--endpoint', type=str, default='oss-cn-shanghai-internal.aliyuncs.com', help='endpoint')
+    down_parser.add_argument('--local', nargs='+', default='', help='local path')
+    down_parser.add_argument('--object', nargs='+', default='', help='object name')
+    down_parser.add_argument('--endpoint', type=str, default='', help='endpoint')
     down_parser.add_argument('--use_tar', action='store_true', help='uncompress the give local file')
     down_parser.add_argument('--use_control_signal', action='store_true', help='write control signal in file')
     down_parser.add_argument('--signal_path', type=str, default='/tmp/ossctl-signal', help='path to write signal')
